@@ -14,8 +14,28 @@ from imagekit.utils import img_to_fobj
 # Modify image file buffer size.
 ImageFile.MAXBLOCK = getattr(settings, 'PIL_IMAGEFILE_MAXBLOCK', 256 * 2 ** 10)
 
+# Choice tuples for specifying the crop origin.
+# These are provided for convenience.
+CROP_HORZ_CHOICES = (
+    (0, _('left')),
+    (1, _('center')),
+    (2, _('right')),
+)
+
+CROP_VERT_CHOICES = (
+    (0, _('top')),
+    (1, _('center')),
+    (2, _('bottom')),
+)
+
 
 class ImageModelBase(ModelBase):
+    """ ImageModel metaclass
+    
+    This metaclass parses IKOptions and loads the specified specification
+    module.
+    
+    """
     def __init__(cls, name, bases, attrs):
         parents = [b for b in bases if isinstance(b, ImageModelBase)]
         if not parents:
@@ -39,7 +59,8 @@ class ImageModelBase(ModelBase):
 class ImageModel(models.Model):
     """ Abstract base class implementing all core ImageKit functionality
     
-    Subclasses of ImageModel can override the inner IKOptions class to customize
+    Subclasses of ImageModel are augmented with accessors for each defined
+    image specification and can override the inner IKOptions class to customize
     storage locations and other options.
     
     """
@@ -52,6 +73,8 @@ class ImageModel(models.Model):
         pass
         
     def admin_thumbnail_view(self):
+        if not self._imgfield:
+            return None
         prop = getattr(self, self._ik.admin_thumbnail_spec, None)
         if prop is None:
             return 'An "%s" image spec has not been defined.' % \
@@ -103,7 +126,7 @@ class ImageModel(models.Model):
                 name = str(self._imgfield)
                 self._imgfield.storage.delete(name)
                 self._imgfield.storage.save(name, content)
-        if clear_cache:
+        if clear_cache and self._imgfield != '':
             self._clear_cache()
             self._pre_cache()
 
